package com.caimei.service.auth;

import com.caimei.model.ResponseJson;
import com.caimei.model.po.CmBrandDoctorPo;
import com.caimei.model.vo.DoctorFormVo;
import com.caimei.model.vo.DoctorListVo;
import com.caimei.model.vo.WxDoctorListVo;
import com.github.pagehelper.PageInfo;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2022/1/7
 */
public interface DoctorService {

    /**
     * 医师列表
     *
     * @param listType   列表类型：1医师列表，2医师审核列表
     * @param authUserId 供应商用户id
     * @param doctorName  医师
     * @param certificateNo
     * @param status    上线状态：0已下线，1已上线，2待上线
     * @param auditStatus  审核状态:0审核未通过，1审核通过，2待审核
     * @param pageNum    第几页
     * @param pageSize   一页多少条
     * @return DoctorListVo
     */
    ResponseJson<PageInfo<DoctorListVo>> getDoctorList(Integer listType, Integer authUserId, String doctorName, String certificateNo, Integer status, Integer auditStatus, Integer pageNum, Integer pageSize);

    /**
     * 更新医师状态
     *
     * @param doctorId 医师id
     * @param status 医师状态:0停用 1启用
     * @return ResponseJson
     */
    ResponseJson updateDoctorStatus(Integer doctorId, Integer status);

    /**
     * 删除医师
     * @param doctorId    医师id
     * @return  ResponseJson
     */
    ResponseJson deleteDoctor(Integer doctorId);

    /**
     * 添加/编辑医师
     *
     * @param doctor       医师机构
     * @param bannerList 轮播图列表
     * @param equipmentList 仪器列表
     * @return ResponseJson
     */
    ResponseJson saveDoctor(CmBrandDoctorPo doctor, List<String> bannerList, List<Map<String,Object>> equipmentList);

    /**
     * 审核品牌医师
     *
     * @param doctorId            医师id
     * @param auditStatus       审核状态
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return ResponseJson
     */
    ResponseJson auditDoctor(Integer doctorId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 医师回显数据
     * @param doctorId    医师id
     * @return
     */
    ResponseJson<DoctorFormVo> getDoctorFormData(Integer doctorId);

    /**
     * 微信公众号医师列表
     * @param appId
     * @param doctorName
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PageInfo<WxDoctorListVo>> getWxDoctorList(String appId, String doctorName, Integer pageNum, Integer pageSize);

    /**
     * 认证医师详情
     * @param doctorId
     * @return
     */
    ResponseJson<DoctorFormVo> getAuthDoctorDetails(Integer doctorId);
}
