package com.caimei.service.auth.impl;

import com.caimei.mapper.AuthMapper;
import com.caimei.mapper.AuthProductMapper;
import com.caimei.mapper.ClubMapper;
import com.caimei.mapper.ShopMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.ClubUserPo;
import com.caimei.model.vo.*;
import com.caimei.service.auth.AuthClubService;
import com.caimei.utils.CodeUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Slf4j
@Service
public class AuthClubServiceImpl implements AuthClubService {

    @Resource
    private ClubMapper clubMapper;

    @Resource
    private AuthMapper authMapper;

    @Resource
    private ShopMapper shopMapper;

    @Resource
    private AuthProductMapper authProductMapper;

    @Override
    public ResponseJson<PageInfo<ClubVo>> getClubList( Integer authUserId, String clubName, Integer pageNum, Integer pageSize) {
        if (null == authUserId) {
            return ResponseJson.error("参数异常，请输入供应商用户id", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<ClubVo> clubList = clubMapper.getClubList(authUserId, clubName);
        PageInfo<ClubVo> pageData = new PageInfo<>(clubList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<PageInfo<ClubUserVo>> getClubUserList(Integer authId, String mobile, Integer status, Integer pageNum, Integer pageSize) {
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权机构id", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<ClubUserVo> clubUserList = clubMapper.getClubUserList(authId, mobile, status);
        PageInfo<ClubUserVo> pageData = new PageInfo<>(clubUserList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson generateCode(Integer authId) {
        // 生成邀请码
        String invitationCode = CodeUtil.generateCodeInt(6);
        Date currentTime = new Date();
        Calendar calendar = new GregorianCalendar();
        calendar.setTime(currentTime);
        calendar.add(Calendar.DATE,1);
        Date tomorrowTime = calendar.getTime();
        // 构建机构用户
        ClubUserPo clubUser = new ClubUserPo();
        clubUser.setAuthId(authId);
        clubUser.setAddTime(currentTime);
        clubUser.setUpdateTime(currentTime);
        clubUser.setInvitationCode(invitationCode);
        clubUser.setStatus(0);
        clubUser.setInvitationCodeTime(tomorrowTime);
        // 插入机构用户
        clubMapper.insertClubUser(clubUser);
        return ResponseJson.success("生成邀请码成功");
    }

    @Override
    public ResponseJson unbindCode(Integer clubUserId) {
        Integer status = clubMapper.getStatusByClubUserId(clubUserId);
        if (1 != status) {
            return ResponseJson.error("该邀请码未绑定，无法解绑");
        }
        clubMapper.unbindClubUser(clubUserId);
        return ResponseJson.success("解绑成功");
    }

    @Override
    public ResponseJson updateCode(Integer clubUserId) {
        Integer status = clubMapper.getStatusByClubUserId(clubUserId);
        if (1 == status) {
            return ResponseJson.error("该邀请码已绑定用户，无法更新");
        }
        Date updateTime = new Date();
        Calendar calendar = new GregorianCalendar();
        calendar.setTime(updateTime);
        calendar.add(Calendar.DATE,1);
        Date invitationCodeTime = calendar.getTime();
        String invitationCode = CodeUtil.generateCodeInt(6);
        clubMapper.updateCode(clubUserId, invitationCode, updateTime, invitationCodeTime);
        return ResponseJson.success("更新邀请码成功");
    }

    @Override
    public ResponseJson<PageInfo<WxClubListVo>> getWxClubList(String appId, String lngAndLat, String clubName, Integer provinceId,
                                                              Integer cityId, Integer townId, Integer pageNum, Integer pageSize) {
        if (null == appId) {
            return ResponseJson.error("参数异常，请输入供应商公众号appId", null);
        }
        log.info("查询机构数据，经纬度：" + lngAndLat);
        Double lng = null;
        Double lat = null;
        if (StringUtils.isNotEmpty(lngAndLat)) {
            String[] split = lngAndLat.split(",");
            lng = Double.parseDouble(split[0]);
            lat = Double.parseDouble(split[1]);
        }
        List<WxClubListVo> clubList = clubMapper.getWxClubList(appId, clubName, provinceId, cityId, townId, lng, lat);
        PageInfo<WxClubListVo> pageData = new PageInfo<>(clubList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson submitFeedback(Integer clubUserId, String content) {
        if (null == clubUserId) {
            return ResponseJson.error("参数异常，请输入机构用户id");
        }
        if (StringUtils.isEmpty(content)) {
            return ResponseJson.error("参数异常，请输入反馈内容");
        }
        clubMapper.insertFeedback(clubUserId, content);
        return ResponseJson.success("提交成功");
    }

    @Override
    public ResponseJson<WxClubDetailsVo> getWxClubDetails(Integer authId) {
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入机构id", null);
        }
        WxClubDetailsVo clubDetail = clubMapper.getClubDetails(authId);
        if (null == clubDetail) {
            return ResponseJson.error("机构不存在", null);
        }
        // 轮播图列表
        List<String> bannerList = authMapper.getBannerList(clubDetail.getAuthId());
        clubDetail.setBannerList(bannerList);
        // 授权设备列表
        List<WxProductListVo> wxProductList = authProductMapper.getClubProductList(authId);
        clubDetail.setProductList(wxProductList);
        return ResponseJson.success(clubDetail);
    }

    @Override
    public ResponseJson<WxShopVo> getWxShopInfo(String appId) {
        if (StringUtils.isEmpty(appId)) {
            return ResponseJson.error("参数异常，请输入appId", null);
        }
        WxShopVo shop = shopMapper.getWxShopInfo(appId);
        if (null == shop) {
            return ResponseJson.error("供应商不存在", null);
        }
        return ResponseJson.success(shop);
    }
}
